#include <iostream>
#include "roothreshold.h"
#include "RooAbsReal.h"

RooThreshold::RooThreshold(const char *name, const char *title,
                        RooAbsReal& _x,
                        RooAbsReal& _norm,
                        RooAbsReal& _offset,
                        RooAbsReal& _power,
                        RooAbsReal& _coeff1,
                        RooAbsReal& _coeff2) :
   RooAbsPdf(name,title),
   x("x","x",this,_x),
   norm("norm","norm",this,_norm),
   offset("offset","offset",this,_offset),
   power("power","power",this,_power),
   coeff1("coeff1","coeff1",this,_coeff1),
   coeff2("coeff2","coeff2",this,_coeff2)
{
}


RooThreshold::RooThreshold(const RooThreshold& other, const char* name) :
   RooAbsPdf(other,name),
   x("x",this,other.x),
   norm("norm",this,other.norm),
   offset("offset",this,other.offset),
   power("power",this,other.power),
   coeff1("coeff1",this,other.coeff1),
   coeff2("coeff2",this,other.coeff2)
{
}

Double_t RooThreshold::evaluate() const {

  double ret = 0.0;
  double delx = x - offset;

  if(delx > 0.0) {
    double val1 = pow(delx, power);
    double val2 = coeff1 * delx + coeff2 * delx * delx;
    if(val2 < 50.0) {
      ret = norm * val1 * exp(val2);
    }
  }

  return(ret);
}



